Name: openssh
Version: 8.1p1
Release: 1
License: BSD-3-Clause
Summary: Open Source Secure Shell
Url: https://www.openssh.com/portable.html

BuildRequires: openssl-devel >= 1.1
BuildRequires: zlib-devel

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: m4-gnu

Source0: ftp://mirror.esc7.net/pub/OpenBSD/OpenSSH/portable/openssh-%{version}.tar.gz

Patch50: openssh-reorganize-aix-port.patch
Patch51: openssh-add-pase-support.patch
Patch52: openssh-no-setgroups-on-ibmi.patch
Patch53: openssh-pase-password-auth-support.patch
Patch54: openssh-fix-tests.patch

%description
OpenSSH is the premier connectivity tool for remote login with the SSH protocol.
It encrypts all traffic to eliminate eavesdropping, connection hijacking, and
other attacks. In addition, OpenSSH provides a large suite of secure tunneling
capabilities, several authentication methods, and sophisticated configuration
options.

%package server
Summary: An open source SSH server

%description server
OpenSSH is the premier connectivity tool for remote login with the SSH protocol.
It encrypts all traffic to eliminate eavesdropping, connection hijacking, and
other attacks. In addition, OpenSSH provides a large suite of secure tunneling
capabilities, several authentication methods, and sophisticated configuration
options.

WARNING: This sshd server is provided for testing only. It is not a replacement
for the version provided by 5733-SC1.

%prep
%setup -q

%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1

autoreconf -fi

%build

%configure \
  ac_cv_func_fchmodat=no \
  ac_cv_func_fchownat=no \
  ac_cv_func_utimensat=no \
  ac_cv_func_clock_gettime=no \
  ac_cv_func_getpeereid=no \
  blibpath=%{_libdir}:/QOpenSys/usr/lib \
  --with-cflags="-std=c99" \
  --sysconfdir=%{_sysconfdir}/ssh \
  --with-pid-dir=/tmp \
  --with-sandbox=rlimit \
  --with-privsep-user=qsshd \
  --with-privsep-path=%{_var}/empty-sshd \
  --with-default-path=/QOpenSys/usr/bin:/usr/ccs/bin:/QOpenSys/usr/bin/X11:/usr/sbin:/usr/bin:%{_bindir} \
  --without-pam \
  --without-rpath \
  --disable-utmp \
  --disable-utmpx \
  --disable-wtmp \
  --disable-wtmpx \
  --disable-libutil \
  %if "%{_bindir}" != "%{_sbindir}"
  --sbindir=%{_bindir}
  %endif
  # end

%make_build all

%install

%make_install

install -c -m 0755 contrib/ssh-copy-id   %{buildroot}%{_bindir}
install -c -m  644 contrib/ssh-copy-id.1 %{buildroot}%{_mandir}/cat1

mkdir -p %{buildroot}%{_prefix}/sbin
ln -s %{_bindir}/sshd %{buildroot}%{_prefix}/sbin/sshd


%files
%defattr(-, qsys, *none)

%{_bindir}/ssh
%{_bindir}/scp
%{_bindir}/ssh-add
%{_bindir}/ssh-agent
%{_bindir}/ssh-keygen
%{_bindir}/ssh-keyscan
%{_bindir}/sftp
%{_bindir}/ssh-copy-id

%{_mandir}/cat1/ssh.1*
%{_mandir}/cat1/scp.1*
%{_mandir}/cat1/ssh-add.1*
%{_mandir}/cat1/ssh-agent.1*
%{_mandir}/cat1/ssh-copy-id.1*
%{_mandir}/cat1/ssh-keygen.1*
%{_mandir}/cat1/ssh-keyscan.1*
%{_mandir}/cat1/sftp.1*

%{_mandir}/cat5/ssh_config.5*

%{_mandir}/cat8/ssh-keysign.8*
%{_mandir}/cat8/ssh-pkcs11-helper.8*

%{_libexecdir}/ssh-keysign
%{_libexecdir}/ssh-pkcs11-helper

%{_sysconfdir}/ssh/ssh_config
%{_sysconfdir}/ssh/moduli

%files server
%defattr(-, qsys, *none)

%{_prefix}/sbin/sshd

%{_bindir}/sshd

%{_libexecdir}/sftp-server

%{_sysconfdir}/ssh/sshd_config

%{_mandir}/cat5/moduli.5*
%{_mandir}/cat5/sshd_config.5*

%{_mandir}/cat8/sshd.8*
%{_mandir}/cat8/sftp-server.8*

%{_var}/empty-sshd


%changelog
* Mon Dec 20 2021 Mark Irish <mirish@ibm.com> - 8.1p1
- Move sshd binary from .../sbin/ to .../bin/
- Create sshd symlink from old .../sbin location to .../bin

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 8.1p1
- Use generic paths for man and info pages to allow for compression

* Thu Dec 12 2019 Kevin Adler <kadler@us.ibm.com> - 8.1p1
- Upgrade to 8.1p1
- Link to OpenSSL 1.1 instead of 1.0.2

* Wed Dec 11 2019 Kevin Adler <kadler@us.ibm.com> - 6.9p1
- Use SPDX license identifier
- Create server subpackage for sshd
- Clean up description and line wrap at 80 columns
- Clean up build flags: -maix64, -I, & -L now set by GCC automatically
- Set autoconf envvars to better handle clock_gettime and getpeereid
- Use different sandbox directory as SC1 to prevent conflicts
- General cleanups

* Tue Oct 01 2019 Kevin Adler <kadler@us.ibm.com> - 6.9p1
- Fix build. There's no iconv-pase package

* Mon Mar 12 2018 - Kevin Adler <kadler@us.ibm.com>
- Add unshipped files

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Fix descriptions and summaries copied from openssl spec file
- use perl -pie instead of GNU sed -i
- Add build requirements

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add BuildConflicts since openssh requires PASE libiconv

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use auto dependency resolution instead of requiring pase-libs

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix 64-bit builds in various packages

* Thu Aug 17 2017 - Kevin Adler <kadler@us.ibm.com>
- Patch Makefile to fix link error with -brtl and static archives
- Use configure macro and fix various parameters
- Set OBJECT_MODE during install section
- Install ssh-copy-id files during build

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add spec files
